"use strict" ;

import 'polyfill/Object.js' ;

import { dump }      from './core/dump.js' ;
import { sayHello }  from './core/hello.js' ;
import { skipHello } from './core/hello.js' ;
import { trace }     from './core/trace.js' ;

import { cancelAnimationFrame  } from './core/requestAnimationFrame.js' ;
import { requestAnimationFrame } from './core/requestAnimationFrame.js' ;

import { performance  } from './core/performance.js' ;

import { isBoolean } from './core/isBoolean.js' ;
import { isFloat   } from './core/isFloat.js' ;
import { isInt     } from './core/isInt.js' ;
import { isNumber  } from './core/isNumber.js' ;
import { isUint    } from './core/isUint.js' ;
import { isString  } from './core/isString.js' ;

import { arrays   } from './core/arrays.js' ;
import { chars    } from './core/chars.js' ;
import { colors   } from './core/colors.js' ;
import { date     } from './core/date.js' ;
import { dom      } from './core/dom.js' ;
import { easings  } from './core/easings.js' ;
import { functors } from './core/functors.js' ;
import { maths    } from './core/maths.js' ;
import { numbers  } from './core/numbers.js' ;
import { objects  } from './core/objects.js' ;
import { random   } from './core/random.js' ;
import { reflect  } from './core/reflect.js' ;
import { strings  } from './core/strings.js' ;

/**
 * The {@link core} package is specialized in functions utilities that are highly reusable without creating any dependencies : arrays, strings, chars, objects, numbers, maths, date, colors, etc.
 * <p>You can consider a library as a set of functions organized into classes, here with a <strong>"core"</strong> library in some cases we organize the functions in the package definitions without assembling them into a class.</p>
 * <p>Those functions are allowed to reuse the builtin types (Object, Array, Date, etc.), the Javascript API classes and packages, but nothing else.</p>
 * @summary The {@link core} package is specialized in functions utilities that are highly reusable without creating any dependencies.
 * @license {@link https://www.mozilla.org/en-US/MPL/2.0/)|MPL 2.0} / {@link https://www.gnu.org/licenses/old-licenses/gpl-2.0.fr.html|GPL 2.0} / {@link https://www.gnu.org/licenses/old-licenses/lgpl-2.1.fr.html|LGPL 2.1}
 * @author Marc Alcaraz <ekameleon@gmail.com>
 * @namespace core
 * @version 1.0.7
 * @since 1.0.0
 */
export var core = Object.assign
({
    dump : dump ,
    sayHello : sayHello,
    skipHello : skipHello,
    trace : trace,

    /**
     * Cancels an animation frame request previously scheduled through a call to </code>requestAnimationFrame</code>.
     * @module cancelAnimationFrame
     * @memberof core
     * @instance
     * @function
     * @param {number} requestID - The ID value returned by the call to </code>requestAnimationFrame</code> that requested the callback.
     * @example
     * var start = performance.now() ;
     * var id ;
     *
     * function step( timestamp )
     * {
     *     var progress = timestamp - start;
     *     console.log( 'step: ' + progress ) ;
     *     if (progress < 2000)
     *     {
     *         id = requestAnimationFrame(step);
     *     }
     * }
     *
     * id = requestAnimationFrame(step);
     *
     * cancelAnimationFrame(id); // abord the animation
     */
    cancelAnimationFrame  : cancelAnimationFrame ,

    /**
     * A Performance object offering access to the performance and timing-related information offered by the APIs it exposes.
     * @module performance
     * @memberof core
     * @instance
     */
    performance : performance ,

    /**
     * The <code>requestAnimationFrame()</code> method tells the browser that you wish to perform an animation and requests that the browser call a specified function to update an animation before the next repaint. The method takes as an argument a callback to be invoked before the repaint.
     * @module requestAnimationFrame
     * @function
     * @instance
     * @memberof core
     * @param {Function} callback - A parameter specifying a function to call when it's time to update your animation for the next repaint. The callback has one single argument, a <code>DOMHighResTimeStamp</code>, which indicates the current time (the time returned from <code>Performance.now()</code> ) for when requestAnimationFrame starts to fire callbacks.
     * @return {number} A long integer value, the request id, that uniquely identifies the entry in the callback list. This is a non-zero value, but you may not make any other assumptions about its value. You can pass this value to window.cancelAnimationFrame() to cancel the refresh callback request.
     * @example
     * var start = performance.now() ;
     *
     * function step( timestamp )
     * {
     *     var progress = timestamp - start;
     *     console.log( 'step: ' + progress ) ;
     *     if (progress < 2000)
     *     {
     *         id = requestAnimationFrame(step);
     *     }
     * }
     *
     * var id = requestAnimationFrame(step);
     */
    requestAnimationFrame : requestAnimationFrame ,

    isBoolean : isBoolean ,
    isFloat   : isFloat ,
    isInt     : isInt ,
    isNumber  : isNumber ,
    isString  : isString ,
    isUint    : isUint ,

    arrays   : arrays ,
    chars    : chars ,
    colors   : colors ,
    date     : date ,
    dom      : dom ,
    easings  : easings,
    functors : functors,
    maths    : maths ,
    numbers  : numbers,
    objects  : objects ,
    random   : random ,
    reflect  : reflect ,
    strings  : strings
}) ;