"use strict" ;

/**
 * Returns the instance of a public definition in a specific <code>domain</code> object.
 * @name invoke
 * @memberof core.reflect
 * @function
 * @instance
 * @param {string} name - The name of the full qualified path of a definition (instance, class, etc).
 * @param {Object} [domain] - An object or namespace who contains the definition object.
 * @example
 * var definition = core.reflect.getDefinitionByName('system.signals.Signal') ;
 * trace( definition ) ;
 */
export function getDefinitionByName( name , domain = null )
{
    if( ( name instanceof String ) || typeof(name) === 'string' )
    {
        let elements = name.split('.') ;
        if( elements.length > 0 )
        {
            try
            {
                let o = domain ;
                elements.forEach( ( element ) =>
                {
                    if(o.hasOwnProperty(element) )
                    {
                        o = o[element] ;
                    }
                    else
                    {
                        return undefined ;
                    }
                });
                return o ;
            }
            catch( ignored ) {}
        }
    }
    return undefined ;
}