/* jshint -W079 */
"use strict" ;

import { performance } from './performance.js' ;

let ca ;
let ra ;

if( window )
{
    const ONE_FRAME_TIME = 16;

    let lastTime = Date.now();

    const vendors = ['ms', 'moz', 'webkit', 'o'] ;

    let len = vendors.length ;
    for ( let x = 0 ; x < len && !window.requestAnimationFrame ; ++x )
    {
        const p = vendors[x];

        window.requestAnimationFrame = window[`${p}RequestAnimationFrame`];
        window.cancelAnimationFrame  = window[`${p}CancelAnimationFrame`] || global[`${p}CancelRequestAnimationFrame`];
    }

    if (!window.requestAnimationFrame)
    {
        window.requestAnimationFrame = ( callback ) =>
        {
            if ( typeof callback !== 'function' )
            {
                throw new TypeError(`${callback}is not a function`) ;
            }

            const currentTime = Date.now();

            let delay = ONE_FRAME_TIME + lastTime - currentTime;

            if ( delay < 0 )
            {
                delay = 0;
            }

            lastTime = currentTime;

            return setTimeout(() =>
            {
                lastTime = Date.now();
                callback( performance.now() );
            }, delay);
        };
    }

    if (!window.cancelAnimationFrame)
    {
        window.cancelAnimationFrame = (id) => clearTimeout(id);
    }

    ca = window.cancelAnimationFrame ;
    ra = window.requestAnimationFrame ;
}

export var cancelAnimationFrame  = ca ;
export var requestAnimationFrame = ra ;