"use strict" ;

import 'polyfill/index.js' ;

import { sayHello } from './core/hello.js' ;
import { ucFirst }  from './core/strings/ucFirst.js' ;

/**
 * The vegas-core JS library.
 * @license {@link https://www.mozilla.org/en-US/MPL/2.0/|MPL 2.0} / {@link https://www.gnu.org/licenses/old-licenses/gpl-2.0.fr.html|GPL 2.0} / {@link https://www.gnu.org/licenses/old-licenses/lgpl-2.1.fr.html|LGPL 2.1}
 * @author Marc Alcaraz <ekameleon@gmail.com>
 */
export { sayHello }  from './core/hello.js' ;
export { skipHello } from './core/hello.js' ;
export { trace }     from './core/trace.js' ;

export { dump } from './core/dump.js' ;

export { performance }           from './core/performance.js' ;
export { cancelAnimationFrame }  from './core/requestAnimationFrame.js' ;
export { requestAnimationFrame } from './core/requestAnimationFrame.js' ;

export { isBoolean } from './core/isBoolean.js' ;
export { isFloat } from './core/isFloat.js' ;
export { isInt } from './core/isInt.js' ;
export { isNumber } from './core/isNumber.js' ;
export { isString } from './core/isString.js' ;
export { isUint } from './core/isUint.js' ;

export { arrays }   from './core/arrays.js' ;
export { chars }    from './core/chars.js' ;
export { colors }   from './core/colors.js' ;
export { date }     from './core/date.js' ;
export { dom }      from './core/dom.js' ;
export { easings }  from './core/easings.js' ;
export { functors } from './core/functors.js' ;
export { maths }    from './core/maths.js' ;
export { numbers }  from './core/numbers.js' ;
export { objects }  from './core/objects.js' ;
export { random }   from './core/random.js' ;
export { reflect }  from './core/reflect.js' ;
export { strings }  from './core/strings.js' ;

/**
 * The string expression of the current VEGAS version.
 * @name version
 * @type string
 * @global
 */
export const version = '<@VERSION@>' ;

/**
 * The metadatas object to describe the <b>VEGAS JS</b> framework.
 * @name metas
 * @property {string} name - The name of the library
 * @property {string} description - The description of the library
 * @property {string} version - The version of the library
 * @property {string} license - The license of the library
 * @property {string} url - The url of the library
 * @type Object
 * @global
 * @example
 * trace( core.dump( metas ) ) ;
 */
export const metas = Object.defineProperties( {} ,
{
    name        : { enumerable : true , value : ucFirst('<@NAME@>') } ,
    description : { enumerable : true , value : "<@DESCRIPTION@>" },
    version     : { enumerable : true , value : version } ,
    license     : { enumerable : true , value : "<@LICENSE@>" } ,
    url         : { enumerable : true , value : '<@HOMEPAGE@>' }
});

try
{
    if ( window )
    {
        window.addEventListener( 'load' , function load()
        {
            window.removeEventListener( "load", load, false ) ;
            sayHello(metas.name,metas.version,metas.url) ;
        }, false );
    }
}
catch( ignored ) {}
